@@ -3,6 +3,9 @@ The ``mlflow.entities`` module defines entities returned by the MLflow
 `REST API <../rest-api.html>`_.
 """
 
+from mlflow.entities.auth_enums import EntityType, Role, SubjectType
+from mlflow.entities.columns import Columns
+from mlflow.entities.entity_subject_role import EntitySubjectRole
 from mlflow.entities.experiment import Experiment
 from mlflow.entities.experiment_tag import ExperimentTag
 from mlflow.entities.file_info import FileInfo
@@ -12,13 +15,11 @@ from mlflow.entities.param import Param
 from mlflow.entities.run import Run
 from mlflow.entities.run_data import RunData
 from mlflow.entities.run_info import RunInfo
+from mlflow.entities.run_log import RunLog
 from mlflow.entities.run_status import RunStatus
 from mlflow.entities.run_tag import RunTag
 from mlflow.entities.source_type import SourceType
 from mlflow.entities.view_type import ViewType
-from mlflow.entities.auth_enums import SubjectType, EntityType, Role
-from mlflow.entities.entity_subject_role import EntitySubjectRole
-from mlflow.entities.columns import Columns
 
 __all__ = [
     "Experiment",
@@ -39,4 +40,5 @@ __all__ = [
     "Role",
     "EntitySubjectRole",
     "Columns",
+    "RunLog",
 ]
