@@ -1,39 +1,43 @@
 import typing
 
-from mlflow.entities import Experiment, Run, RunInfo, Metric, ViewType
+from mlflow.entities import Experiment, Metric, Run, RunInfo, RunLog, ViewType
 from mlflow.exceptions import MlflowException
 from mlflow.protos import databricks_pb2
 from mlflow.protos.service_pb2 import (
     CreateExperiment,
-    MlflowService,
-    GetExperiment,
-    GetRun,
-    SearchRuns,
-    ListExperiments,
-    GetMetricHistory,
-    LogMetric,
-    LogParam,
-    SetTag,
-    UpdateRun,
     CreateRun,
-    DeleteRun,
-    RestoreRun,
     DeleteExperiment,
-    RestoreExperiment,
-    UpdateExperiment,
-    LogBatch,
-    LogModel,
+    DeleteRun,
     DeleteTag,
-    SetExperimentTag,
+    GetExperiment,
     GetExperimentByName,
+    GetLatestRunLog,
+    GetMetricHistory,
+    GetRun,
+    ListExperiments,
+    ListRunLogs,
+    LogBatch,
+    LogMetric,
+    LogModel,
+    LogParam,
+    MlflowService,
+    RestoreExperiment,
+    RestoreRun,
+    RunLogInput,
+    SearchRuns,
+    SetExperimentTag,
+    SetTag,
+    StoreRunLogs,
+    UpdateExperiment,
+    UpdateRun,
 )
-from mlflow.store.tracking.abstract_store import AbstractStore
 from mlflow.store.entities.paged_list import PagedList
+from mlflow.store.tracking.abstract_store import AbstractStore
 from mlflow.utils.proto_json_utils import message_to_json
 from mlflow.utils.rest_utils import (
+    _REST_API_PATH_PREFIX,
     call_endpoint,
     extract_api_info_for_service,
-    _REST_API_PATH_PREFIX,
 )
 
 _METHOD_TO_INFO = extract_api_info_for_service(MlflowService, _REST_API_PATH_PREFIX)
@@ -316,6 +320,37 @@ class RestStore(AbstractStore):
         req_body = message_to_json(LogModel(run_id=run_id, model_json=mlflow_model.to_json()))
         self._call_endpoint(LogModel, req_body)
 
+    def insert_run_logs(self, run_uuid: str, run_logs: typing.List[RunLog]):
+        request_body_proto = StoreRunLogs(run_uuid=run_uuid)
+        request_body_proto.run_logs.extend(
+            RunLogInput(
+                key=run_log.key,
+                step=run_log.step,
+                timestamp=run_log.timestamp,
+                log_type=run_log.log_type,
+                value=run_log.value,
+                artifact_path=run_log.artifact_path,
+            )
+            for run_log in run_logs
+        )
+
+        request_body = message_to_json(request_body_proto)
+        self._call_endpoint(StoreRunLogs, request_body)
+
+    def get_latest_run_log(self, run_uuid: str, key: str, log_type: str) -> RunLog:
+        request_body_proto = GetLatestRunLog(run_uuid=run_uuid, key=key, log_type=log_type)
+        request_body = message_to_json(request_body_proto)
+        response_proto = self._call_endpoint(GetLatestRunLog, request_body)
+        return RunLog.from_proto(response_proto.run_log)
+
+    def list_run_logs(
+        self, run_uuid: str, key: typing.Optional[str] = None, log_type: typing.Optional[str] = None
+    ) -> typing.List[RunLog]:
+        request_body_proto = ListRunLogs(run_uuid=run_uuid, key=key or "", log_type=log_type or "")
+        request_body = message_to_json(request_body_proto)
+        response_proto = self._call_endpoint(ListRunLogs, request_body)
+        return [RunLog.from_proto(run_log) for run_log in response_proto.run_logs]
+
 
 class DatabricksRestStore(RestStore):
     """
